package Giblog::Command::new_blog;

use base 'Giblog::Command::new';

use strict;
use warnings;

1;

=encoding utf8

=head1 NAME

Giblog::Command::new_blog - Blog creating command

=head1 DESCRIPTION

L<Giblog::Command::new_blog> is a command to create blog.

=head1 METHODS

L<Giblog::Command::new_blog> inherits all methods from L<Giblog::Command::new> and
implements the following new ones.
